package com.yunzhi.liyuanhui.controller;

import com.yunzhi.liyuanhui.common.*;
import com.yunzhi.liyuanhui.entity.SysUser;
import com.yunzhi.liyuanhui.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

@RestController
public class LoginController extends BaseController {

    @Autowired
    ISysUserService iSysUserService;

    @PostMapping("/login")
    public ResponseBean login(@RequestBody Map<String, String> loginParam) throws Exception {
        if (null == loginParam) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String userName = loginParam.get("userName");
        String password = loginParam.get("password");

        if (StringUtils.isEmpty(userName) || StringUtils.isEmpty(password)) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        SysUser sysUser = iSysUserService.getLoginUser(userName);
        if (null == sysUser) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!checkPassword(password, sysUser.getPassword(), sysUser.getUserId().toString())) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!iSysUserService.checkStatus(sysUser)) {
            return ResponseBean.error("用户状态不正确, 请联系管理人员", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 生成 token
        Map<String, Object> claims = new HashMap<String, Object>(){{
            put("userId", sysUser.getUserId());
        }};
        String jws = JWTUtils.encode(claims);
        sysUser.setPassword(null);
        sysUser.setToken(jws);

        return ResponseBean.success(sysUser);
    }

    private boolean checkPassword(String src, String targ, String salt) {
        return EncryptUtils.md5(src, salt).equals(targ);
    }
}
