package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ISysUserService;
import com.yunzhi.liyuanhui.entity.SysUser;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 系统用户 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class SysUserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysUserController.class);

    @Autowired
    public ISysUserService iSysUserService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/sysUser",method= RequestMethod.GET)
    public ResponseBean sysUserList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {

        //使用分页插件
        IPage<SysUser> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        IPage<SysUser> result = iSysUserService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param sysUser 实体对象
     * @return
     */
    @RequestMapping(value="/sysUser",method= RequestMethod.POST)
    public ResponseBean sysUserAdd(@RequestBody SysUser sysUser) throws Exception{

        if (iSysUserService.save(sysUser)){
            return ResponseBean.success(sysUser);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysUser/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysUserDelete(@PathVariable Integer id) throws Exception {

        if(iSysUserService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysUser 实体对象
     * @return
     */
    @RequestMapping(value="/sysUser/{id}",method= RequestMethod.PUT)
    public ResponseBean sysUserUpdate(@PathVariable Integer id,
                                        @RequestBody SysUser sysUser) throws Exception{

        if (iSysUserService.updateById(sysUser)){
            return ResponseBean.success(sysUser);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysUser/{id}",method= RequestMethod.GET)
    public ResponseBean sysUserGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iSysUserService.getById(id));
    }
}
