package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaActivityService;
import com.yunzhi.liyuanhui.entity.TaActivity;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 活动 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaActivityController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaActivityController.class);

    @Autowired
    public ITaActivityService iTaActivityService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taActivity",method= RequestMethod.GET)
    public ResponseBean taActivityList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaActivity> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaActivity> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        IPage<TaActivity> result = iTaActivityService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taActivity 实体对象
     * @return
     */
    @RequestMapping(value="/taActivity",method= RequestMethod.POST)
    public ResponseBean taActivityAdd(@RequestBody TaActivity taActivity) throws Exception{

        if (iTaActivityService.save(taActivity)){
            return ResponseBean.success(taActivity);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taActivity/{id}", method= RequestMethod.DELETE)
    public ResponseBean taActivityDelete(@PathVariable Integer id) throws Exception{

        if(iTaActivityService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taActivity 实体对象
     * @return
     */
    @RequestMapping(value="/taActivity/{id}",method= RequestMethod.PUT)
    public ResponseBean taActivityUpdate(@PathVariable Integer id,
                                        @RequestBody TaActivity taActivity) throws Exception{

        if (iTaActivityService.updateById(taActivity)){
            return ResponseBean.success(taActivity);
        }else {
            return ResponseBean.error("更新失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taActivity/{id}",method= RequestMethod.GET)
    public ResponseBean taActivityGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaActivityService.getById(id));
    }
}
