package com.yunzhi.liyuanhui.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.liyuanhui.common.BaseController;
import com.yunzhi.liyuanhui.common.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.liyuanhui.service.ITaPersonService;
import com.yunzhi.liyuanhui.entity.TaPerson;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 用户 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-08-08
 */
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public ITaPersonService iTaPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPerson",method= RequestMethod.GET)
    public ResponseBean taPersonList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                     @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
    public ResponseBean taPersonAdd(@RequestBody TaPerson taPerson) throws Exception{

        if (iTaPersonService.save(taPerson)){
            return ResponseBean.success(taPerson);
        }else {
            return ResponseBean.error("保存失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
    public ResponseBean taPersonDelete(@PathVariable Integer id) throws Exception{

        if(iTaPersonService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.PUT)
    public ResponseBean taPersonUpdate(@PathVariable Integer id,
                                        @RequestBody TaPerson taPerson) throws Exception{

        if (iTaPersonService.updateById(taPerson)){
            return ResponseBean.success(taPerson);
        }else {
            return ResponseBean.error("修改失败", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.GET)
    public ResponseBean taPersonGet(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaPersonService.getById(id));
    }
}
